@@ -18,6 +18,7 @@ Common Options:
 import getopt
 import sys
 import os
+import glob
 import signal
 import subprocess
 import functools
@@ -245,12 +246,23 @@ def leaves(dir_or_file, allow_symlinks = True, ignore_hidden_file = True):
 def with_exit(fnc):
     return sys.exit(fnc())
 
+def valid_directories(directory):
+    '''wrapper for glob.glob, enforces that output must be a valid directory'''
+    directories = [dir for dir in glob.glob(directory) if os.path.isdir(dir)]
+    directories.reverse #to use the newest version, in case we have foo-version
+    return directories
+
 def path_to_executable(name, directory=None):
     """
-    construct the path to the executable, check the directory specified
+    construct the path to the executable, search in order
+    
+    the directory specified (or any directory that matches with Unix
+                             style pathname pattern expansion*)
     then env PATH
     then the current directory
     then give up
+
+    *we reverse the order so that we will usually get the newest version
     """
     # if name is a list, iterate over it to find exe and catch errors
     if type(name) is list:
@@ -263,11 +275,12 @@ def path_to_executable(name, directory=None):
                     ", ".join(name))
 
     #try specified directory
-    if directory is not None:
-        full_path = os.path.join(directory, name)
-        if os.path.exists(full_path):
-            if os.access(full_path, os.X_OK):
-                return full_path
+    for directory in valid_directories(directory):
+        if directory is not None:
+            full_path = os.path.join(directory, name)
+            if os.path.exists(full_path):
+                if os.access(full_path, os.X_OK):
+                    return full_path
     #try PATH
     try: PATH = os.environ['PATH']
     except NameError:
